@@ -1,14 +1,15 @@
 #!/bin/sh
 echo 'name: enumerator
-version: 0.4.14
-id: enumerator-0.4.14-9c33aff818231fce81258e5fdfab7c93
+version: 0.4.19
+id: enumerator-0.4.19-13fa8f89bd8effdb12c1bcec44c8658a
 
 license: MIT
-copyright: Copyright (c) John Millikin 2010-2011
+copyright: 2010-2011 John Millikin, 2011 Mikhail Vorozhtsov
 maintainer: jmillikin@gmail.com
 stability: experimental
 homepage: https://john-millikin.com/software/enumerator/
 package-url:
+synopsis: Reliable, high-performance processing with left-fold enumerators
 description: Typical buffer&#x2013;based incremental I/O is based around a single loop,
              which reads data from some source (such as a socket or file), transforms
              it, and generates one or more outputs (such as a line count, HTTP
@@ -51,25 +52,27 @@ author: John Millikin <jmillikin@gmail.com>
 pkgpath: devel/hs-enumerator
 exposed: True
 exposed-modules: Data.Enumerator Data.Enumerator.Binary
-                 Data.Enumerator.Text Data.Enumerator.List Data.Enumerator.IO
-hidden-modules: Data.Enumerator.Util
-import-dirs: /usr/local/lib/ghc/enumerator-0.4.14
-library-dirs: /usr/local/lib/ghc/enumerator-0.4.14
-hs-libraries: HSenumerator-0.4.14
+                 Data.Enumerator.Internal Data.Enumerator.IO Data.Enumerator.List
+                 Data.Enumerator.Text Data.Enumerator.Trans
+hidden-modules: Data.Enumerator.Compatibility Data.Enumerator.Util
+trusted: False
+import-dirs: /usr/local/lib/ghc/enumerator-0.4.19
+library-dirs: /usr/local/lib/ghc/enumerator-0.4.19
+hs-libraries: HSenumerator-0.4.19
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
-         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
-         containers-0.4.0.0-b4885363abca642443ccd842502a3b7e
-         text-0.11.1.5-24dbc1ca0a1252804bf8bef893d5cf9c
-         transformers-0.2.2.0-4bbbfde1fb5c4eb17cdb1963dda698f3
+depends: base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
+         bytestring-0.10.0.2-9e8b487747800a4255d6ff7915c5210f
+         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
+         text-0.11.3.1-06d227f06409a354e0c77a385328bada
+         transformers-0.3.0.0-ff2bb6ac67241ebb987351a3db564af0
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-enumerator-0.4.14/html/enumerator.haddock
-haddock-html: /usr/local/share/doc/hs-enumerator-0.4.14/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-enumerator-0.4.19/html/enumerator.haddock
+haddock-html: /usr/local/share/doc/hs-enumerator-0.4.19/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
